==> kdevplatform-1.6.90.tar.xz: kdevplatform-1.6.90/plugins/projectmanagerview/kdevprojectmanagerview.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Comment=Lets you manage the project contents.
Comment[bs]=Omogućava vam upravljanje sadržajem projekta
Comment[ca]=Us permet gestionar els continguts del projecte.
Comment[ca@valencia]=Vos permet gestionar els continguts del projecte.
Comment[da]=Lader dig håndtere projektets indhold.
Comment[de]=Lässt Sie den Inhalt Ihres Projekts verwalten.
Comment[el]=Σας επιτρέπει τη διαχείριση του περιεχομένου του έργου
Comment[en_GB]=Lets you manage the project contents.
Comment[es]=Le permite gestionar el contenido del proyecto.
Comment[et]=Projektide sisu haldamine
Comment[fi]=Sallii projektien sisällön hallinnan.
Comment[fr]=Permet de gérer le contenu des projets.
Comment[gl]=Permítelle xestionar os contidos do proxecto.
Comment[hu]=Kezelheti a projekttartalmakat.
Comment[it]=Consente di gestire il contenuto del progetto.
Comment[kk]=Жоба мазмұнын басқаруы.
Comment[nb]=Brukes til å styre prosjektinnholdet.
Comment[nds]=Dien Projektinholden plegen
Comment[nl]=Laat u de projectinhoud beheren.
Comment[pl]=Pozwala tobie na zarządzanie zawartością projektu.
Comment[pt]=Permite-lhe gerir o conteúdo do projecto.
Comment[pt_BR]=Permite-lhe gerenciar o conteúdo do projeto.
Comment[ru]=Позволяет управлять содержимым проектов
Comment[sk]=Umožní vám spravovať obsah projektu.
Comment[sl]=Vam pomaga upravljati z vsebino projekta.
Comment[sv]=Låter dig hantera projektets innehåll.
Comment[tr]=Proje içindekileri yönetmenizi sağlar.
Comment[ug]=قۇرۇلۇش مەزمۇنىنى باشقۇرۇڭ.
Comment[uk]=Надає вам змогу керувати вмістом проектів.
Comment[x-test]=xxLets you manage the project contents.xx
Comment[zh_CN]=让您管理项目内容。
Comment[zh_TW]=讓您管理您的專案內容。
Name=Project Manager View
Name[bg]=Преглед на редактора на проекти
Name[bs]=Pregled menadžera projekta
Name[ca]=Vista del gestor de projectes
Name[ca@valencia]=Vista del gestor de projectes
Name[da]=Visning af projekthåndtering
Name[de]=Ansicht für Projektverwaltung
Name[el]=Προβολή διαχειριστή έργου
Name[en_GB]=Project Manager View
Name[es]=Vista del gestor de proyectos
Name[et]=Projektihalduri vaade
Name[fi]=Projektihallintanäkymä
Name[fr]=Vue du gestionnaire de projets
Name[gl]=Vista do xestor de proxectos
Name[hu]=Projektkezelő nézet
Name[it]=Vista gestore progetto
Name[ja]=プロジェクトマネージャのビュー
Name[kk]=Жоба менеджер көрінісі
Name[nb]=Prosjektbehandlervisning
Name[nds]=Projektpleger-Ansicht
Name[nl]=Projectbeheerder-overzicht
Name[pa]=ਪਰੋਜੈਕਟ ਮੈਨੇਜਰ ਝਲਕ
Name[pl]=Widok zarządcy projektu
Name[pt]=Área do Gestor de Projectos
Name[pt_BR]=Visualizador do gerenciador de projeto
Name[ru]=Панель управления проектами
Name[sk]=Pohľad na správcu projektu
Name[sl]=Prikaz upravljalnika projektov
Name[sv]=Projekthanteringsvy
Name[tr]=Proje Yöneticisi Görünümü
Name[ug]=قۇرۇلۇش باشقۇرغۇ كۆرۈنۈشى
Name[uk]=Перегляд керування проектами
Name[x-test]=xxProject Manager Viewxx
Name[zh_CN]=工程管理器视图
Name[zh_TW]=專案管理員檢視
GenericName=Project Manager View
GenericName[bg]=Преглед на редактора на проекти
GenericName[bs]=Pregled menadžera projekta
GenericName[ca]=Vista del gestor de projectes
GenericName[ca@valencia]=Vista del gestor de projectes
GenericName[da]=Visning af projekthåndtering
GenericName[de]=Ansicht für Projektverwaltung
GenericName[el]=Προβολή διαχειριστή έργου
GenericName[en_GB]=Project Manager View
GenericName[es]=Vista del gestor de proyectos
GenericName[et]=Projektihalduri vaade
GenericName[fi]=Projektinhallintanäkymä
GenericName[fr]=Vue du gestionnaire de projets
GenericName[gl]=Vista do xestor de proxectos
GenericName[hu]=Projektkezelő nézet
GenericName[it]=Vista gestore progetto
GenericName[ja]=プロジェクトマネージャのビュー
GenericName[kk]=Жоба менеджер көрінісі
GenericName[nb]=Prosjektbehandlervisning
GenericName[nds]=Projektpleger-Ansicht
GenericName[nl]=Projectbeheerder-overzicht
GenericName[pl]=Widok zarządcy projektu
GenericName[pt]=Área do Gestor de Projectos
GenericName[pt_BR]=Visualizador do gerenciador de projeto
GenericName[ru]=Панель управления проектами
GenericName[sk]=Pohľad na správcu projektu
GenericName[sl]=Prikaz upravljalnika projektov
GenericName[sv]=Projekthanteringsvy
GenericName[tr]=Proje Yönetimi Görünümü
GenericName[ug]=قۇرۇلۇش باشقۇرغۇ كۆرۈنۈشى
GenericName[uk]=Перегляд керування проектами
GenericName[x-test]=xxProject Manager Viewxx
GenericName[zh_CN]=工程管理器视图
GenericName[zh_TW]=專案管理員檢視
Icon=kdevelop
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevprojectmanagerview
X-KDE-PluginInfo-Name=KDevProjectManagerView
X-KDE-PluginInfo-Author=Roberto Raggi
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-Category=Core
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Mode=GUI

==> kdevplatform_1.7.0.orig.tar.xz: kdevplatform-1.7.0/plugins/projectmanagerview/kdevprojectmanagerview.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Comment=Lets you manage the project contents.
Comment[bs]=Omogućava vam upravljanje sadržajem projekta
Comment[ca]=Us permet gestionar els continguts del projecte.
Comment[ca@valencia]=Vos permet gestionar els continguts del projecte.
Comment[da]=Lader dig håndtere projektets indhold.
Comment[de]=Lässt Sie den Inhalt Ihres Projekts verwalten.
Comment[el]=Σας επιτρέπει τη διαχείριση του περιεχομένου του έργου
Comment[en_GB]=Lets you manage the project contents.
Comment[es]=Le permite gestionar el contenido del proyecto.
Comment[et]=Projektide sisu haldamine
Comment[fi]=Sallii projektien sisällön hallinnan.
Comment[fr]=Permet de gérer le contenu des projets.
Comment[gl]=Permítelle xestionar os contidos do proxecto.
Comment[hu]=Kezelheti a projekttartalmakat.
Comment[it]=Consente di gestire il contenuto del progetto.
Comment[kk]=Жоба мазмұнын басқаруы.
Comment[nb]=Brukes til å styre prosjektinnholdet.
Comment[nds]=Dien Projektinholden plegen
Comment[nl]=Laat u de projectinhoud beheren.
Comment[pl]=Pozwala tobie na zarządzanie zawartością projektu.
Comment[pt]=Permite-lhe gerir o conteúdo do projecto.
Comment[pt_BR]=Permite-lhe gerenciar o conteúdo do projeto.
Comment[ru]=Позволяет управлять содержимым проектов
Comment[sk]=Umožní vám spravovať obsah projektu.
Comment[sl]=Vam pomaga upravljati z vsebino projekta.
Comment[sv]=Låter dig hantera projektets innehåll.
Comment[tr]=Proje içindekileri yönetmenizi sağlar.
Comment[ug]=قۇرۇلۇش مەزمۇنىنى باشقۇرۇڭ.
Comment[uk]=Надає вам змогу керувати вмістом проектів.
Comment[x-test]=xxLets you manage the project contents.xx
Comment[zh_CN]=让您管理项目内容。
Comment[zh_TW]=讓您管理您的專案內容。
Name=Project Manager View
Name[bg]=Преглед на редактора на проекти
Name[bs]=Pregled menadžera projekta
Name[ca]=Vista del gestor de projectes
Name[ca@valencia]=Vista del gestor de projectes
Name[da]=Visning af projekthåndtering
Name[de]=Ansicht für Projektverwaltung
Name[el]=Προβολή διαχειριστή έργου
Name[en_GB]=Project Manager View
Name[es]=Vista del gestor de proyectos
Name[et]=Projektihalduri vaade
Name[fi]=Projektihallintanäkymä
Name[fr]=Vue du gestionnaire de projets
Name[gl]=Vista do xestor de proxectos
Name[hu]=Projektkezelő nézet
Name[it]=Vista gestore progetto
Name[ja]=プロジェクトマネージャのビュー
Name[kk]=Жоба менеджер көрінісі
Name[nb]=Prosjektbehandlervisning
Name[nds]=Projektpleger-Ansicht
Name[nl]=Projectbeheerder-overzicht
Name[pa]=ਪਰੋਜੈਕਟ ਮੈਨੇਜਰ ਝਲਕ
Name[pl]=Widok menadżera projektu
Name[pt]=Área do Gestor de Projectos
Name[pt_BR]=Visualizador do gerenciador de projeto
Name[ru]=Панель управления проектами
Name[sk]=Pohľad na správcu projektu
Name[sl]=Prikaz upravljalnika projektov
Name[sv]=Projekthanteringsvy
Name[tr]=Proje Yöneticisi Görünümü
Name[ug]=قۇرۇلۇش باشقۇرغۇ كۆرۈنۈشى
Name[uk]=Перегляд керування проектами
Name[x-test]=xxProject Manager Viewxx
Name[zh_CN]=工程管理器视图
Name[zh_TW]=專案管理員檢視
GenericName=Project Manager View
GenericName[bg]=Преглед на редактора на проекти
GenericName[bs]=Pregled menadžera projekta
GenericName[ca]=Vista del gestor de projectes
GenericName[ca@valencia]=Vista del gestor de projectes
GenericName[da]=Visning af projekthåndtering
GenericName[de]=Ansicht für Projektverwaltung
GenericName[el]=Προβολή διαχειριστή έργου
GenericName[en_GB]=Project Manager View
GenericName[es]=Vista del gestor de proyectos
GenericName[et]=Projektihalduri vaade
GenericName[fi]=Projektinhallintanäkymä
GenericName[fr]=Vue du gestionnaire de projets
GenericName[gl]=Vista do xestor de proxectos
GenericName[hu]=Projektkezelő nézet
GenericName[it]=Vista gestore progetto
GenericName[ja]=プロジェクトマネージャのビュー
GenericName[kk]=Жоба менеджер көрінісі
GenericName[nb]=Prosjektbehandlervisning
GenericName[nds]=Projektpleger-Ansicht
GenericName[nl]=Projectbeheerder-overzicht
GenericName[pl]=Widok menadżera projektu
GenericName[pt]=Área do Gestor de Projectos
GenericName[pt_BR]=Visualizador do gerenciador de projeto
GenericName[ru]=Панель управления проектами
GenericName[sk]=Pohľad na správcu projektu
GenericName[sl]=Prikaz upravljalnika projektov
GenericName[sv]=Projekthanteringsvy
GenericName[tr]=Proje Yönetimi Görünümü
GenericName[ug]=قۇرۇلۇش باشقۇرغۇ كۆرۈنۈشى
GenericName[uk]=Перегляд керування проектами
GenericName[x-test]=xxProject Manager Viewxx
GenericName[zh_CN]=工程管理器视图
GenericName[zh_TW]=專案管理員檢視
Icon=kdevelop
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevprojectmanagerview
X-KDE-PluginInfo-Name=KDevProjectManagerView
X-KDE-PluginInfo-Author=Roberto Raggi
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-Category=Core
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Mode=GUI
